# DIAMONDS

Original creators: Enrico Corsaro & Joris De Ridder

The DIAMONDS (high-DImensional And multi-MOdal NesteD Sampling) code performs a Bayesian parameter estimation and model comparison by means of the nested sampling Monte Carlo (NSMC) algorithm. The code was designed to be generally applicable to a large variety of problems. Diamonds is developed in C++11 and is structured in classes for flexibility and configurability. Any new model, likelihood and prior probability density functions can be defined and implemented, deriving from an abstract class.

For more information, see the documentation in the docs/ folder.
